#
# spec file for package xfce4-netload-plugin
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define panel_version 4.12.0
%define plugin netload
%bcond_with git
Name:           xfce4-%{plugin}-plugin
Version:        1.4.1
Release:        bp156.1.5
Summary:        Network Load Monitoring Plugin for the Xfce Panel
License:        GPL-2.0-or-later
Group:          System/GUI/XFCE
URL:            https://docs.xfce.org/panel-plugins/xfce4-netload-plugin
Source0:        https://archive.xfce.org/src/panel-plugins/%{name}/1.4/%{name}-%{version}.tar.bz2
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0) >= 2.50.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.0
BuildRequires:  pkgconfig(libxfce4panel-2.0) >= %{panel_version}
BuildRequires:  pkgconfig(libxfce4ui-2) >= 4.12.0
%if %{with git}
BuildRequires:  xfce4-dev-tools
%endif
Requires:       xfce4-panel >= %{panel_version}
Recommends:     %{name}-lang = %{version}
# package was renamed in 2019 after Leap 15.1
Provides:       xfce4-panel-plugin-%{plugin} = %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin} < %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin}-debuginfo

%description
The Netload plugin allows to monitor the netowrk load of a given network
interface.

%package lang
Summary:        Translations for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
Supplements:    %{name}
Provides:       %{name}-lang-all = %{version}
# package was renamed in 2019 after Leap 15.1
Obsoletes:      xfce4-panel-plugin-%{plugin}-lang < %{version}-%{release}
Provides:       xfce4-panel-plugin-%{plugin}-lang = %{version}-%{release}
BuildArch:      noarch

%description lang
Provides translations for the "%{name}" package.

%prep
%autosetup

%build
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
  --enable-maintainer-mode \
  --disable-static
%else
%configure --disable-static
%endif
%make_build

%install
%make_install

rm %{buildroot}%{_libdir}/xfce4/panel/plugins/libnetload.la

%find_lang %{name} %{name}.lang %{?no_lang_C}

%fdupes %{buildroot}%{_datadir}

%files
%doc AUTHORS NEWS README
%license COPYING
%{_libdir}/xfce4/panel/plugins/libnetload.so
%{_datadir}/xfce4/panel/plugins/netload.desktop
%{_datadir}/icons/hicolor/*/apps/org.xfce.panel.netload.*

%files lang -f %{name}.lang

%changelog
* Sat Apr 29 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 1.4.1
  * Fix wrong description in about dialog
  * Fix wrong units in bytes (Fixes #22)
  * Update copyright year
  * Add option to set number of decimal points (Closes #21)
  * build: Fix intltool lock file problem during make distcheck
  * build: Add GLib requirement
  * build: Fix autotools warnings
  * Update COPYING
  * Check if ip_address string is non-empty
  * Free memory only after last reference
  * Reset source id to prevent double free
  * Translation Updates
* Thu Mar 11 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.4.0
  * Add new icons and switch to rDNS naming
  * Add "About" dialog
  * Add help button to properties dialog
  * Improve progressbar look
  * Update URLs from goodies.x.o to docs.x.o (bxo#16170)
  * Fix compilation warnings
  * autoconf: AM_CONFIG_HEADER -> AC_CONFIG_HEADERS
  * Update `.gitignore`
  * Fix missing-prototypes
  * Remove GSourceFunc casts
  * Populate a combo box with known network interfaces
  * remove unused wormulon files
  * Move to common m4 versioning macros
  * Fix type for media_list on OpenBSD
  * Add basic GitLab pipeline
  * Translation Updates
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Wed Aug 14 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 1.3.2
  - Preferences: Improve spacing (bxo#14672)
  - Fix stats on some openbsd drivers (bxo#13853)
  - set a name on the 'text to display' widget so that it can be styled
    (closes bxo#13906)
  - Fix bxo#11477, bxo#12957, bxo#11328
  - css styling improvements
  - fix autotools warnings
- Dropped obsolete patch xfce4-netload-plugin-fix-array-out-of-bounds.patch
* Tue Jul 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Package renamed to follow upstream name xfce4-foo-plugin
- Use lang subpackage for manual edits instead of %%lang_package macro
- Cleaned up spec file
- Added bcond for git master builds
- Move COPYING under %%license macro
- Renamed patch xfce4-panel-plugin-netload-fix-array-out-of-bounds.patch
  to xfce4-netload-plugin-fix-array-out-of-bounds.patch
* Wed Apr 19 2017 seife+obs@b1-systems.com
- update to version 1.3.1
  - set progressbar minimal width and height depending on
    orientation (bxo#12941, bxo#12949)
  - apply css on the correct widget class for Gtk 3.16/3.18
  - rework the use of GtkCssProvider to use a singleton
  - translation updates
* Sun Nov 27 2016 seife+obs@b1-systems.com
- update to version 1.3.0
  - port to gtk+3/libxfce4ui-2/libxfce4panel-2.0
  - fix progress bar grow direction in deskbar and vertical modes
- do not package ChangeLog; NEWS is good enough
* Sun Nov 23 2014 gber@opensuse.org
- update to version 1.2.4
  - option to show values as bits
  - reverted "Do not enforce max length for text/device entries"
  - set iface length name to 32 chars max
  - translation updates
- add xfce4-panel-plugin-netload-fix-array-out-of-bounds.patch in
  order to fix an array out of bounds write (bxo#11328)
* Sat Nov 15 2014 gber@opensuse.org
- update to version 1.2.3
  - fix a small bug reported by JR, with really big values the code
    segfaulted in the format_byte_humanreadable function
* Sun Nov  2 2014 gber@opensuse.org
- update to version 1.2.2
  - fix plugin installation path
* Sun Nov  2 2014 gber@opensuse.org
- update to version 1.2.1
  - build plugin as a module
  - update build environment
  - only round to 0 digits for KiB/s values
  - pack progress bars inside event box and hide/show
  - do not enforce max length for text/device entries
  - fix stringsize - 1
* Sun Jul 15 2012 gber@opensuse.org
- update to version 1.2.0
  - some code cleanup and respect the Panel HIG
  - update monitor labels sizes gracefully
  - rectify tooltip information
  - support new panel mode Deskbar
  - drop if_ppp headers
  - reorganize code in monitor_new, setup_monitor and
    monitor_set_orientation
  - keep colorized values after orientation change
  - fix widget visibility on orientation change
* Fri Apr 20 2012 gber@opensuse.org
- added documentation files
* Tue Apr 17 2012 gber@opensuse.org
- corrected source URL
* Tue Apr  3 2012 gber@opensuse.org
- specfile cleanup
- split off -lang subpackage
* Fri Jan 13 2012 gber@opensuse.org
- update to version 1.1.0
  - add option to show values in panel in addition to the bars
  - format units automatically
  - port to libxfce4ui
  - fix two calls to snprintf
* Wed Mar  9 2011 gber@opensuse.org
- new package (split off from xfce4-panel-plugins)
